@@ -1,12 +1,14 @@
 from .richpath import RichPath, AzurePath, LocalPath
-from .iterators import ThreadedIterator, BufferedIterator, DoubleBufferedIterator, MultiWorkerCallableIterator, shuffled_iterator, uniform_sample_iterator
+from .iterators import ThreadedIterator, BufferedIterator, DoubleBufferedIterator, MultiWorkerCallableIterator, \
+    shuffled_iterator, uniform_sample_iterator, subsample_iterator
 from .dataloading import load_json_gz, save_json_gz, load_jsonl_gz, save_jsonl_gz
 from .gitlog import git_tag_run
 from .debughelper import run_and_debug
 from .chunkwriter import ChunkWriter
 
 __all__ = ['RichPath', 'AzurePath', 'LocalPath',
-           'ThreadedIterator', 'BufferedIterator', 'DoubleBufferedIterator', 'MultiWorkerCallableIterator', 'shuffled_iterator', 'uniform_sample_iterator',
+           'ThreadedIterator', 'BufferedIterator', 'DoubleBufferedIterator', 'MultiWorkerCallableIterator', 'shuffled_iterator',
+           'subsample_iterator', 'uniform_sample_iterator',
            'load_json_gz', 'save_json_gz', 'load_jsonl_gz', 'save_jsonl_gz',
            'git_tag_run',
            'run_and_debug',
